@@ -197,7 +197,9 @@ class BetfairExchangeConnection():
 
                     'Home_odds': np.nan,
                     'Draw_odds': np.nan,
-                    'Away_odds': np.nan
+                    'Away_odds': np.nan,
+
+                    'Approx_time':datetime.now().strftime("%Y-%m-%d %H:%M:%S")
                 }, index=[0])
             
             return na_df
